@@ -3,9 +3,15 @@ from executor import DBError
 from .dialect import Dialect
 from functools import lru_cache
 from .log_support import sql_log
-from .constant import CACHE_SIZE, NAMED_REGEX
+from executor.sql_support import require_limit
 from typing import Collection, Union, List, Tuple
-from executor.sql_support import require_limit, limit_one_sql_args
+from .constant import CACHE_SIZE, NAMED_REGEX, LIMIT_1
+
+
+def limit_one_sql_args(sql: str, *args):
+    if require_limit(sql):
+        return '{} LIMIT ?'.format(sql), [*args, LIMIT_1]
+    return sql, args
 
 
 def insert_sql(table: str, cols: Collection[str]):
